@@ -74,8 +74,14 @@ export interface PipelineTask {
   taskSpec?: PipelineTaskSpec;
   params?: PipelineTaskParam[];
   resources?: PipelineTaskResources;
+  workspaces?: PipelineTaskWorkspace[];
+}
+export interface PipelineTaskWorkspace {
+  name: string;
+  description?: string;
+  mountPath?: string;
+  readOnly?: boolean;
 }
-
 export interface Resource {
   propsReferenceForRuns: string[];
   resources: FirehoseResource[];
@@ -103,6 +109,8 @@ export type PipelineRunReferenceResource = PipelineRunResourceCommonProperties &
 };
 export type PipelineRunResource = PipelineRunReferenceResource | PipelineRunInlineResource;
 
+export type PipelineWorkspace = Param;
+
 export interface Runs {
   data?: PipelineRun[];
 }
@@ -120,11 +128,37 @@ export interface Pipeline extends K8sResourceKind {
   };
 }
 
-export type TaskRunKind = { pipelineTaskName?: string } & K8sResourceKind;
+/** TODO: Define */
+export type TaskRunKind = K8sResourceKind;
 
-export interface TaskRuns {
-  [key: string]: TaskRunKind;
-}
+export type PLRTaskRunStep = {
+  container: string;
+  imageID: string;
+  name: string;
+  terminated?: {
+    containerID: string;
+    exitCode: number;
+    finishedAt: string;
+    reason: string;
+    startedAt: string;
+  };
+};
+
+export type PLRTaskRunData = {
+  pipelineTaskName: string;
+  status: {
+    completionTime?: string;
+    conditions: Condition[];
+    /** Can be empty */
+    podName: string;
+    startTime: string;
+    steps?: PLRTaskRunStep[];
+  };
+};
+
+export type PLRTaskRuns = {
+  [taskRunName: string]: PLRTaskRunData;
+};
 
 export interface PipelineRun extends K8sResourceKind {
   spec?: {
@@ -143,7 +177,7 @@ export interface PipelineRun extends K8sResourceKind {
     conditions?: Condition[];
     startTime?: string;
     completionTime?: string;
-    taskRuns?: TaskRuns;
+    taskRuns?: PLRTaskRuns;
   };
 }
 
@@ -225,13 +259,6 @@ export type VolumeTypePVC = {
   claimName: string;
 };
 
-export interface PipelineWorkspace extends Param {
-  type: string;
-  data?: {
-    [volumeType: string]: VolumeTypeSecret | VolumeTypeConfigMaps | VolumeTypePVC | {};
-  };
-}
-
 export interface PipelineRunWorkspace extends Param {
   [volumeType: string]: VolumeTypeSecret | VolumeTypeConfigMaps | VolumeTypePVC | {};
 }
@@ -400,11 +427,16 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
         taskStatus[runStatus.Pending]++;
       }
     });
-    taskStatus[runStatus.Failed] > 0 || taskStatus[runStatus.Cancelled] > 0
-      ? (taskStatus[runStatus.Cancelled] +=
-          totalTasks >= plrTaskLength ? totalTasks - plrTaskLength : totalTasks)
-      : (taskStatus[runStatus.Pending] +=
-          totalTasks >= plrTaskLength ? totalTasks - plrTaskLength : totalTasks);
+
+    const pipelineRunHasFailure = taskStatus[runStatus.Failed] > 0;
+    const pipelineRunIsCancelled = pipelineRunFilterReducer(pipelinerun) === runStatus.Cancelled;
+    const unhandledTasks = totalTasks >= plrTaskLength ? totalTasks - plrTaskLength : totalTasks;
+
+    if (pipelineRunHasFailure || pipelineRunIsCancelled) {
+      taskStatus[runStatus.Cancelled] += unhandledTasks;
+    } else {
+      taskStatus[runStatus.Pending] += unhandledTasks;
+    }
   } else if (
     pipelinerun &&
     pipelinerun.status &&
